# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/prediction/proto/fnn_model_base.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/prediction/proto/fnn_model_base.proto',
  package='apollo.prediction',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n-modules/prediction/proto/fnn_model_base.proto\x12\x11\x61pollo.prediction\"\x19\n\x06Vector\x12\x0f\n\x07\x63olumns\x18\x01 \x03(\x01\"1\n\x06Matrix\x12\'\n\x04rows\x18\x01 \x03(\x0b\x32\x19.apollo.prediction.Vector\"\xa8\x02\n\x05Layer\x12\x17\n\x0flayer_input_dim\x18\x01 \x01(\x05\x12\x18\n\x10layer_output_dim\x18\x02 \x01(\x05\x12\x35\n\x12layer_input_weight\x18\x03 \x01(\x0b\x32\x19.apollo.prediction.Matrix\x12-\n\nlayer_bias\x18\x04 \x01(\x0b\x32\x19.apollo.prediction.Vector\x12\x46\n\x15layer_activation_func\x18\x05 \x01(\x0e\x32\'.apollo.prediction.Layer.ActivationFunc\">\n\x0e\x41\x63tivationFunc\x12\x08\n\x04RELU\x10\x00\x12\x08\n\x04TANH\x10\x01\x12\x0b\n\x07SIGMOID\x10\x02\x12\x0b\n\x07SOFTMAX\x10\x03'
)



_LAYER_ACTIVATIONFUNC = _descriptor.EnumDescriptor(
  name='ActivationFunc',
  full_name='apollo.prediction.Layer.ActivationFunc',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RELU', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TANH', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SIGMOID', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SOFTMAX', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=381,
  serialized_end=443,
)
_sym_db.RegisterEnumDescriptor(_LAYER_ACTIVATIONFUNC)


_VECTOR = _descriptor.Descriptor(
  name='Vector',
  full_name='apollo.prediction.Vector',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='columns', full_name='apollo.prediction.Vector.columns', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=68,
  serialized_end=93,
)


_MATRIX = _descriptor.Descriptor(
  name='Matrix',
  full_name='apollo.prediction.Matrix',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rows', full_name='apollo.prediction.Matrix.rows', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=95,
  serialized_end=144,
)


_LAYER = _descriptor.Descriptor(
  name='Layer',
  full_name='apollo.prediction.Layer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='layer_input_dim', full_name='apollo.prediction.Layer.layer_input_dim', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='layer_output_dim', full_name='apollo.prediction.Layer.layer_output_dim', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='layer_input_weight', full_name='apollo.prediction.Layer.layer_input_weight', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='layer_bias', full_name='apollo.prediction.Layer.layer_bias', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='layer_activation_func', full_name='apollo.prediction.Layer.layer_activation_func', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LAYER_ACTIVATIONFUNC,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=147,
  serialized_end=443,
)

_MATRIX.fields_by_name['rows'].message_type = _VECTOR
_LAYER.fields_by_name['layer_input_weight'].message_type = _MATRIX
_LAYER.fields_by_name['layer_bias'].message_type = _VECTOR
_LAYER.fields_by_name['layer_activation_func'].enum_type = _LAYER_ACTIVATIONFUNC
_LAYER_ACTIVATIONFUNC.containing_type = _LAYER
DESCRIPTOR.message_types_by_name['Vector'] = _VECTOR
DESCRIPTOR.message_types_by_name['Matrix'] = _MATRIX
DESCRIPTOR.message_types_by_name['Layer'] = _LAYER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Vector = _reflection.GeneratedProtocolMessageType('Vector', (_message.Message,), {
  'DESCRIPTOR' : _VECTOR,
  '__module__' : 'modules.prediction.proto.fnn_model_base_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.Vector)
  })
_sym_db.RegisterMessage(Vector)

Matrix = _reflection.GeneratedProtocolMessageType('Matrix', (_message.Message,), {
  'DESCRIPTOR' : _MATRIX,
  '__module__' : 'modules.prediction.proto.fnn_model_base_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.Matrix)
  })
_sym_db.RegisterMessage(Matrix)

Layer = _reflection.GeneratedProtocolMessageType('Layer', (_message.Message,), {
  'DESCRIPTOR' : _LAYER,
  '__module__' : 'modules.prediction.proto.fnn_model_base_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.Layer)
  })
_sym_db.RegisterMessage(Layer)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/contrib/lgsvl_msgs/proto/detection2darray.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import header_pb2 as modules_dot_common_dot_proto_dot_header__pb2
from modules.contrib.lgsvl_msgs.proto import detection2d_pb2 as modules_dot_contrib_dot_lgsvl__msgs_dot_proto_dot_detection2d__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/contrib/lgsvl_msgs/proto/detection2darray.proto',
  package='apollo.contrib.lgsvl_msgs',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n7modules/contrib/lgsvl_msgs/proto/detection2darray.proto\x12\x19\x61pollo.contrib.lgsvl_msgs\x1a!modules/common/proto/header.proto\x1a\x32modules/contrib/lgsvl_msgs/proto/detection2d.proto\"u\n\x10\x44\x65tection2DArray\x12%\n\x06header\x18\x01 \x01(\x0b\x32\x15.apollo.common.Header\x12:\n\ndetections\x18\x02 \x03(\x0b\x32&.apollo.contrib.lgsvl_msgs.Detection2Db\x06proto3'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_header__pb2.DESCRIPTOR,modules_dot_contrib_dot_lgsvl__msgs_dot_proto_dot_detection2d__pb2.DESCRIPTOR,])




_DETECTION2DARRAY = _descriptor.Descriptor(
  name='Detection2DArray',
  full_name='apollo.contrib.lgsvl_msgs.Detection2DArray',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.contrib.lgsvl_msgs.Detection2DArray.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='detections', full_name='apollo.contrib.lgsvl_msgs.Detection2DArray.detections', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=173,
  serialized_end=290,
)

_DETECTION2DARRAY.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_DETECTION2DARRAY.fields_by_name['detections'].message_type = modules_dot_contrib_dot_lgsvl__msgs_dot_proto_dot_detection2d__pb2._DETECTION2D
DESCRIPTOR.message_types_by_name['Detection2DArray'] = _DETECTION2DARRAY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Detection2DArray = _reflection.GeneratedProtocolMessageType('Detection2DArray', (_message.Message,), {
  'DESCRIPTOR' : _DETECTION2DARRAY,
  '__module__' : 'modules.contrib.lgsvl_msgs.proto.detection2darray_pb2'
  # @@protoc_insertion_point(class_scope:apollo.contrib.lgsvl_msgs.Detection2DArray)
  })
_sym_db.RegisterMessage(Detection2DArray)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cyber/proto/perf_conf.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='cyber/proto/perf_conf.proto',
  package='apollo.cyber.proto',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1b\x63yber/proto/perf_conf.proto\x12\x12\x61pollo.cyber.proto\"R\n\x08PerfConf\x12\x15\n\x06\x65nable\x18\x01 \x01(\x08:\x05\x66\x61lse\x12/\n\x04type\x18\x02 \x01(\x0e\x32\x1c.apollo.cyber.proto.PerfType:\x03\x41LL*=\n\x08PerfType\x12\t\n\x05SCHED\x10\x01\x12\r\n\tTRANSPORT\x10\x02\x12\x0e\n\nDATA_CACHE\x10\x03\x12\x07\n\x03\x41LL\x10\x04'
)

_PERFTYPE = _descriptor.EnumDescriptor(
  name='PerfType',
  full_name='apollo.cyber.proto.PerfType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SCHED', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRANSPORT', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DATA_CACHE', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALL', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=135,
  serialized_end=196,
)
_sym_db.RegisterEnumDescriptor(_PERFTYPE)

PerfType = enum_type_wrapper.EnumTypeWrapper(_PERFTYPE)
SCHED = 1
TRANSPORT = 2
DATA_CACHE = 3
ALL = 4



_PERFCONF = _descriptor.Descriptor(
  name='PerfConf',
  full_name='apollo.cyber.proto.PerfConf',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enable', full_name='apollo.cyber.proto.PerfConf.enable', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='apollo.cyber.proto.PerfConf.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=4,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=51,
  serialized_end=133,
)

_PERFCONF.fields_by_name['type'].enum_type = _PERFTYPE
DESCRIPTOR.message_types_by_name['PerfConf'] = _PERFCONF
DESCRIPTOR.enum_types_by_name['PerfType'] = _PERFTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PerfConf = _reflection.GeneratedProtocolMessageType('PerfConf', (_message.Message,), {
  'DESCRIPTOR' : _PERFCONF,
  '__module__' : 'cyber.proto.perf_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.proto.PerfConf)
  })
_sym_db.RegisterMessage(PerfConf)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/map/proto/map_signal.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import geometry_pb2 as modules_dot_common_dot_proto_dot_geometry__pb2
from modules.map.proto import map_geometry_pb2 as modules_dot_map_dot_proto_dot_map__geometry__pb2
from modules.map.proto import map_id_pb2 as modules_dot_map_dot_proto_dot_map__id__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/map/proto/map_signal.proto',
  package='apollo.hdmap',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"modules/map/proto/map_signal.proto\x12\x0c\x61pollo.hdmap\x1a#modules/common/proto/geometry.proto\x1a$modules/map/proto/map_geometry.proto\x1a\x1emodules/map/proto/map_id.proto\"\xa1\x02\n\tSubsignal\x12\x1c\n\x02id\x18\x01 \x01(\x0b\x32\x10.apollo.hdmap.Id\x12*\n\x04type\x18\x02 \x01(\x0e\x32\x1c.apollo.hdmap.Subsignal.Type\x12)\n\x08location\x18\x03 \x01(\x0b\x32\x17.apollo.common.PointENU\"\x9e\x01\n\x04Type\x12\x0b\n\x07UNKNOWN\x10\x01\x12\n\n\x06\x43IRCLE\x10\x02\x12\x0e\n\nARROW_LEFT\x10\x03\x12\x11\n\rARROW_FORWARD\x10\x04\x12\x0f\n\x0b\x41RROW_RIGHT\x10\x05\x12\x1a\n\x16\x41RROW_LEFT_AND_FORWARD\x10\x06\x12\x1b\n\x17\x41RROW_RIGHT_AND_FORWARD\x10\x07\x12\x10\n\x0c\x41RROW_U_TURN\x10\x08\"a\n\x08SignInfo\x12)\n\x04type\x18\x01 \x01(\x0e\x32\x1b.apollo.hdmap.SignInfo.Type\"*\n\x04Type\x12\x08\n\x04None\x10\x00\x12\x18\n\x14NO_RIGHT_TURN_ON_RED\x10\x01\"\x92\x03\n\x06Signal\x12\x1c\n\x02id\x18\x01 \x01(\x0b\x32\x10.apollo.hdmap.Id\x12\'\n\x08\x62oundary\x18\x02 \x01(\x0b\x32\x15.apollo.hdmap.Polygon\x12*\n\tsubsignal\x18\x03 \x03(\x0b\x32\x17.apollo.hdmap.Subsignal\x12$\n\noverlap_id\x18\x04 \x03(\x0b\x32\x10.apollo.hdmap.Id\x12\'\n\x04type\x18\x05 \x01(\x0e\x32\x19.apollo.hdmap.Signal.Type\x12&\n\tstop_line\x18\x06 \x03(\x0b\x32\x13.apollo.hdmap.Curve\x12)\n\tsign_info\x18\x07 \x03(\x0b\x32\x16.apollo.hdmap.SignInfo\"s\n\x04Type\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x14\n\x10MIX_2_HORIZONTAL\x10\x02\x12\x12\n\x0eMIX_2_VERTICAL\x10\x03\x12\x14\n\x10MIX_3_HORIZONTAL\x10\x04\x12\x12\n\x0eMIX_3_VERTICAL\x10\x05\x12\n\n\x06SINGLE\x10\x06'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_geometry__pb2.DESCRIPTOR,modules_dot_map_dot_proto_dot_map__geometry__pb2.DESCRIPTOR,modules_dot_map_dot_proto_dot_map__id__pb2.DESCRIPTOR,])



_SUBSIGNAL_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='apollo.hdmap.Subsignal.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CIRCLE', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ARROW_LEFT', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ARROW_FORWARD', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ARROW_RIGHT', index=4, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ARROW_LEFT_AND_FORWARD', index=5, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ARROW_RIGHT_AND_FORWARD', index=6, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ARROW_U_TURN', index=7, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=291,
  serialized_end=449,
)
_sym_db.RegisterEnumDescriptor(_SUBSIGNAL_TYPE)

_SIGNINFO_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='apollo.hdmap.SignInfo.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='None', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NO_RIGHT_TURN_ON_RED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=506,
  serialized_end=548,
)
_sym_db.RegisterEnumDescriptor(_SIGNINFO_TYPE)

_SIGNAL_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='apollo.hdmap.Signal.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MIX_2_HORIZONTAL', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MIX_2_VERTICAL', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MIX_3_HORIZONTAL', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MIX_3_VERTICAL', index=4, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SINGLE', index=5, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=838,
  serialized_end=953,
)
_sym_db.RegisterEnumDescriptor(_SIGNAL_TYPE)


_SUBSIGNAL = _descriptor.Descriptor(
  name='Subsignal',
  full_name='apollo.hdmap.Subsignal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='apollo.hdmap.Subsignal.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='apollo.hdmap.Subsignal.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='location', full_name='apollo.hdmap.Subsignal.location', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SUBSIGNAL_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=160,
  serialized_end=449,
)


_SIGNINFO = _descriptor.Descriptor(
  name='SignInfo',
  full_name='apollo.hdmap.SignInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='apollo.hdmap.SignInfo.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SIGNINFO_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=451,
  serialized_end=548,
)


_SIGNAL = _descriptor.Descriptor(
  name='Signal',
  full_name='apollo.hdmap.Signal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='apollo.hdmap.Signal.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='boundary', full_name='apollo.hdmap.Signal.boundary', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subsignal', full_name='apollo.hdmap.Signal.subsignal', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='overlap_id', full_name='apollo.hdmap.Signal.overlap_id', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='apollo.hdmap.Signal.type', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stop_line', full_name='apollo.hdmap.Signal.stop_line', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sign_info', full_name='apollo.hdmap.Signal.sign_info', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SIGNAL_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=551,
  serialized_end=953,
)

_SUBSIGNAL.fields_by_name['id'].message_type = modules_dot_map_dot_proto_dot_map__id__pb2._ID
_SUBSIGNAL.fields_by_name['type'].enum_type = _SUBSIGNAL_TYPE
_SUBSIGNAL.fields_by_name['location'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINTENU
_SUBSIGNAL_TYPE.containing_type = _SUBSIGNAL
_SIGNINFO.fields_by_name['type'].enum_type = _SIGNINFO_TYPE
_SIGNINFO_TYPE.containing_type = _SIGNINFO
_SIGNAL.fields_by_name['id'].message_type = modules_dot_map_dot_proto_dot_map__id__pb2._ID
_SIGNAL.fields_by_name['boundary'].message_type = modules_dot_map_dot_proto_dot_map__geometry__pb2._POLYGON
_SIGNAL.fields_by_name['subsignal'].message_type = _SUBSIGNAL
_SIGNAL.fields_by_name['overlap_id'].message_type = modules_dot_map_dot_proto_dot_map__id__pb2._ID
_SIGNAL.fields_by_name['type'].enum_type = _SIGNAL_TYPE
_SIGNAL.fields_by_name['stop_line'].message_type = modules_dot_map_dot_proto_dot_map__geometry__pb2._CURVE
_SIGNAL.fields_by_name['sign_info'].message_type = _SIGNINFO
_SIGNAL_TYPE.containing_type = _SIGNAL
DESCRIPTOR.message_types_by_name['Subsignal'] = _SUBSIGNAL
DESCRIPTOR.message_types_by_name['SignInfo'] = _SIGNINFO
DESCRIPTOR.message_types_by_name['Signal'] = _SIGNAL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Subsignal = _reflection.GeneratedProtocolMessageType('Subsignal', (_message.Message,), {
  'DESCRIPTOR' : _SUBSIGNAL,
  '__module__' : 'modules.map.proto.map_signal_pb2'
  # @@protoc_insertion_point(class_scope:apollo.hdmap.Subsignal)
  })
_sym_db.RegisterMessage(Subsignal)

SignInfo = _reflection.GeneratedProtocolMessageType('SignInfo', (_message.Message,), {
  'DESCRIPTOR' : _SIGNINFO,
  '__module__' : 'modules.map.proto.map_signal_pb2'
  # @@protoc_insertion_point(class_scope:apollo.hdmap.SignInfo)
  })
_sym_db.RegisterMessage(SignInfo)

Signal = _reflection.GeneratedProtocolMessageType('Signal', (_message.Message,), {
  'DESCRIPTOR' : _SIGNAL,
  '__module__' : 'modules.map.proto.map_signal_pb2'
  # @@protoc_insertion_point(class_scope:apollo.hdmap.Signal)
  })
_sym_db.RegisterMessage(Signal)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/prediction/proto/fnn_vehicle_model.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.prediction.proto import fnn_model_base_pb2 as modules_dot_prediction_dot_proto_dot_fnn__model__base__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/prediction/proto/fnn_vehicle_model.proto',
  package='apollo.prediction',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n0modules/prediction/proto/fnn_vehicle_model.proto\x12\x11\x61pollo.prediction\x1a-modules/prediction/proto/fnn_model_base.proto\"\xd5\x01\n\x0f\x46nnVehicleModel\x12\x11\n\tdim_input\x18\x01 \x01(\x05\x12/\n\x0csamples_mean\x18\x02 \x01(\x0b\x32\x19.apollo.prediction.Vector\x12.\n\x0bsamples_std\x18\x03 \x01(\x0b\x32\x19.apollo.prediction.Vector\x12\x11\n\tnum_layer\x18\x04 \x01(\x05\x12\'\n\x05layer\x18\x05 \x03(\x0b\x32\x18.apollo.prediction.Layer\x12\x12\n\ndim_output\x18\x06 \x01(\x05'
  ,
  dependencies=[modules_dot_prediction_dot_proto_dot_fnn__model__base__pb2.DESCRIPTOR,])




_FNNVEHICLEMODEL = _descriptor.Descriptor(
  name='FnnVehicleModel',
  full_name='apollo.prediction.FnnVehicleModel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dim_input', full_name='apollo.prediction.FnnVehicleModel.dim_input', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='samples_mean', full_name='apollo.prediction.FnnVehicleModel.samples_mean', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='samples_std', full_name='apollo.prediction.FnnVehicleModel.samples_std', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_layer', full_name='apollo.prediction.FnnVehicleModel.num_layer', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='layer', full_name='apollo.prediction.FnnVehicleModel.layer', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dim_output', full_name='apollo.prediction.FnnVehicleModel.dim_output', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=119,
  serialized_end=332,
)

_FNNVEHICLEMODEL.fields_by_name['samples_mean'].message_type = modules_dot_prediction_dot_proto_dot_fnn__model__base__pb2._VECTOR
_FNNVEHICLEMODEL.fields_by_name['samples_std'].message_type = modules_dot_prediction_dot_proto_dot_fnn__model__base__pb2._VECTOR
_FNNVEHICLEMODEL.fields_by_name['layer'].message_type = modules_dot_prediction_dot_proto_dot_fnn__model__base__pb2._LAYER
DESCRIPTOR.message_types_by_name['FnnVehicleModel'] = _FNNVEHICLEMODEL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FnnVehicleModel = _reflection.GeneratedProtocolMessageType('FnnVehicleModel', (_message.Message,), {
  'DESCRIPTOR' : _FNNVEHICLEMODEL,
  '__module__' : 'modules.prediction.proto.fnn_vehicle_model_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.FnnVehicleModel)
  })
_sym_db.RegisterMessage(FnnVehicleModel)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/localization/proto/pose.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import geometry_pb2 as modules_dot_common_dot_proto_dot_geometry__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/localization/proto/pose.proto',
  package='apollo.localization',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%modules/localization/proto/pose.proto\x12\x13\x61pollo.localization\x1a#modules/common/proto/geometry.proto\"\xa7\x03\n\x04Pose\x12)\n\x08position\x18\x01 \x01(\x0b\x32\x17.apollo.common.PointENU\x12.\n\x0borientation\x18\x02 \x01(\x0b\x32\x19.apollo.common.Quaternion\x12/\n\x0flinear_velocity\x18\x03 \x01(\x0b\x32\x16.apollo.common.Point3D\x12\x33\n\x13linear_acceleration\x18\x04 \x01(\x0b\x32\x16.apollo.common.Point3D\x12\x30\n\x10\x61ngular_velocity\x18\x05 \x01(\x0b\x32\x16.apollo.common.Point3D\x12\x0f\n\x07heading\x18\x06 \x01(\x01\x12\x37\n\x17linear_acceleration_vrf\x18\x07 \x01(\x0b\x32\x16.apollo.common.Point3D\x12\x34\n\x14\x61ngular_velocity_vrf\x18\x08 \x01(\x0b\x32\x16.apollo.common.Point3D\x12,\n\x0c\x65uler_angles\x18\t \x01(\x0b\x32\x16.apollo.common.Point3D'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_geometry__pb2.DESCRIPTOR,])




_POSE = _descriptor.Descriptor(
  name='Pose',
  full_name='apollo.localization.Pose',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='position', full_name='apollo.localization.Pose.position', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orientation', full_name='apollo.localization.Pose.orientation', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='linear_velocity', full_name='apollo.localization.Pose.linear_velocity', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='linear_acceleration', full_name='apollo.localization.Pose.linear_acceleration', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='angular_velocity', full_name='apollo.localization.Pose.angular_velocity', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading', full_name='apollo.localization.Pose.heading', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='linear_acceleration_vrf', full_name='apollo.localization.Pose.linear_acceleration_vrf', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='angular_velocity_vrf', full_name='apollo.localization.Pose.angular_velocity_vrf', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='euler_angles', full_name='apollo.localization.Pose.euler_angles', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=100,
  serialized_end=523,
)

_POSE.fields_by_name['position'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINTENU
_POSE.fields_by_name['orientation'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._QUATERNION
_POSE.fields_by_name['linear_velocity'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_POSE.fields_by_name['linear_acceleration'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_POSE.fields_by_name['angular_velocity'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_POSE.fields_by_name['linear_acceleration_vrf'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_POSE.fields_by_name['angular_velocity_vrf'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_POSE.fields_by_name['euler_angles'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
DESCRIPTOR.message_types_by_name['Pose'] = _POSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Pose = _reflection.GeneratedProtocolMessageType('Pose', (_message.Message,), {
  'DESCRIPTOR' : _POSE,
  '__module__' : 'modules.localization.proto.pose_pb2'
  # @@protoc_insertion_point(class_scope:apollo.localization.Pose)
  })
_sym_db.RegisterMessage(Pose)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/drivers/canbus/proto/can_card_parameter.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/drivers/canbus/proto/can_card_parameter.proto',
  package='apollo.drivers.canbus',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n5modules/drivers/canbus/proto/can_card_parameter.proto\x12\x15\x61pollo.drivers.canbus\"\xa9\x05\n\x10\x43\x41NCardParameter\x12\x43\n\x05\x62rand\x18\x01 \x01(\x0e\x32\x34.apollo.drivers.canbus.CANCardParameter.CANCardBrand\x12\x41\n\x04type\x18\x02 \x01(\x0e\x32\x33.apollo.drivers.canbus.CANCardParameter.CANCardType\x12H\n\nchannel_id\x18\x03 \x01(\x0e\x32\x34.apollo.drivers.canbus.CANCardParameter.CANChannelId\x12G\n\tinterface\x18\x04 \x01(\x0e\x32\x34.apollo.drivers.canbus.CANCardParameter.CANInterface\x12\x14\n\tnum_ports\x18\x05 \x01(\r:\x01\x34\"M\n\x0c\x43\x41NCardBrand\x12\x0c\n\x08\x46\x41KE_CAN\x10\x00\x12\x0b\n\x07\x45SD_CAN\x10\x01\x12\x12\n\x0eSOCKET_CAN_RAW\x10\x02\x12\x0e\n\nHERMES_CAN\x10\x03\")\n\x0b\x43\x41NCardType\x12\x0c\n\x08PCI_CARD\x10\x00\x12\x0c\n\x08USB_CARD\x10\x01\"\xb5\x01\n\x0c\x43\x41NChannelId\x12\x13\n\x0f\x43HANNEL_ID_ZERO\x10\x00\x12\x12\n\x0e\x43HANNEL_ID_ONE\x10\x01\x12\x12\n\x0e\x43HANNEL_ID_TWO\x10\x02\x12\x14\n\x10\x43HANNEL_ID_THREE\x10\x03\x12\x13\n\x0f\x43HANNEL_ID_FOUR\x10\x04\x12\x13\n\x0f\x43HANNEL_ID_FIVE\x10\x05\x12\x12\n\x0e\x43HANNEL_ID_SIX\x10\x06\x12\x14\n\x10\x43HANNEL_ID_SEVEN\x10\x07\"2\n\x0c\x43\x41NInterface\x12\n\n\x06NATIVE\x10\x00\x12\x0b\n\x07VIRTUAL\x10\x01\x12\t\n\x05SLCAN\x10\x02'
)



_CANCARDPARAMETER_CANCARDBRAND = _descriptor.EnumDescriptor(
  name='CANCardBrand',
  full_name='apollo.drivers.canbus.CANCardParameter.CANCardBrand',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FAKE_CAN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ESD_CAN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SOCKET_CAN_RAW', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HERMES_CAN', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=406,
  serialized_end=483,
)
_sym_db.RegisterEnumDescriptor(_CANCARDPARAMETER_CANCARDBRAND)

_CANCARDPARAMETER_CANCARDTYPE = _descriptor.EnumDescriptor(
  name='CANCardType',
  full_name='apollo.drivers.canbus.CANCardParameter.CANCardType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PCI_CARD', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='USB_CARD', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=485,
  serialized_end=526,
)
_sym_db.RegisterEnumDescriptor(_CANCARDPARAMETER_CANCARDTYPE)

_CANCARDPARAMETER_CANCHANNELID = _descriptor.EnumDescriptor(
  name='CANChannelId',
  full_name='apollo.drivers.canbus.CANCardParameter.CANChannelId',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CHANNEL_ID_ZERO', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CHANNEL_ID_ONE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CHANNEL_ID_TWO', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CHANNEL_ID_THREE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CHANNEL_ID_FOUR', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CHANNEL_ID_FIVE', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CHANNEL_ID_SIX', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CHANNEL_ID_SEVEN', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=529,
  serialized_end=710,
)
_sym_db.RegisterEnumDescriptor(_CANCARDPARAMETER_CANCHANNELID)

_CANCARDPARAMETER_CANINTERFACE = _descriptor.EnumDescriptor(
  name='CANInterface',
  full_name='apollo.drivers.canbus.CANCardParameter.CANInterface',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NATIVE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VIRTUAL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SLCAN', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=712,
  serialized_end=762,
)
_sym_db.RegisterEnumDescriptor(_CANCARDPARAMETER_CANINTERFACE)


_CANCARDPARAMETER = _descriptor.Descriptor(
  name='CANCardParameter',
  full_name='apollo.drivers.canbus.CANCardParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='brand', full_name='apollo.drivers.canbus.CANCardParameter.brand', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='apollo.drivers.canbus.CANCardParameter.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_id', full_name='apollo.drivers.canbus.CANCardParameter.channel_id', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interface', full_name='apollo.drivers.canbus.CANCardParameter.interface', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_ports', full_name='apollo.drivers.canbus.CANCardParameter.num_ports', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=4,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CANCARDPARAMETER_CANCARDBRAND,
    _CANCARDPARAMETER_CANCARDTYPE,
    _CANCARDPARAMETER_CANCHANNELID,
    _CANCARDPARAMETER_CANINTERFACE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=81,
  serialized_end=762,
)

_CANCARDPARAMETER.fields_by_name['brand'].enum_type = _CANCARDPARAMETER_CANCARDBRAND
_CANCARDPARAMETER.fields_by_name['type'].enum_type = _CANCARDPARAMETER_CANCARDTYPE
_CANCARDPARAMETER.fields_by_name['channel_id'].enum_type = _CANCARDPARAMETER_CANCHANNELID
_CANCARDPARAMETER.fields_by_name['interface'].enum_type = _CANCARDPARAMETER_CANINTERFACE
_CANCARDPARAMETER_CANCARDBRAND.containing_type = _CANCARDPARAMETER
_CANCARDPARAMETER_CANCARDTYPE.containing_type = _CANCARDPARAMETER
_CANCARDPARAMETER_CANCHANNELID.containing_type = _CANCARDPARAMETER
_CANCARDPARAMETER_CANINTERFACE.containing_type = _CANCARDPARAMETER
DESCRIPTOR.message_types_by_name['CANCardParameter'] = _CANCARDPARAMETER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CANCardParameter = _reflection.GeneratedProtocolMessageType('CANCardParameter', (_message.Message,), {
  'DESCRIPTOR' : _CANCARDPARAMETER,
  '__module__' : 'modules.drivers.canbus.proto.can_card_parameter_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.canbus.CANCardParameter)
  })
_sym_db.RegisterMessage(CANCardParameter)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cyber/proto/parameter.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='cyber/proto/parameter.proto',
  package='apollo.cyber.proto',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1b\x63yber/proto/parameter.proto\x12\x12\x61pollo.cyber.proto\"\xd3\x01\n\x05Param\x12\x0c\n\x04name\x18\x01 \x01(\t\x12+\n\x04type\x18\x02 \x01(\x0e\x32\x1d.apollo.cyber.proto.ParamType\x12\x11\n\ttype_name\x18\x03 \x01(\t\x12\x14\n\nbool_value\x18\x04 \x01(\x08H\x00\x12\x13\n\tint_value\x18\x05 \x01(\x03H\x00\x12\x16\n\x0c\x64ouble_value\x18\x06 \x01(\x01H\x00\x12\x16\n\x0cstring_value\x18\x07 \x01(\tH\x00\x12\x12\n\nproto_desc\x18\x08 \x01(\x0c\x42\r\n\x0boneof_value\"\x19\n\x08NodeName\x12\r\n\x05value\x18\x01 \x01(\t\"\x1a\n\tParamName\x12\r\n\x05value\x18\x01 \x01(\t\"\x1b\n\nBoolResult\x12\r\n\x05value\x18\x01 \x01(\x08\"2\n\x06Params\x12(\n\x05param\x18\x01 \x03(\x0b\x32\x19.apollo.cyber.proto.Param*Q\n\tParamType\x12\x0b\n\x07NOT_SET\x10\x00\x12\x08\n\x04\x42OOL\x10\x01\x12\x07\n\x03INT\x10\x02\x12\n\n\x06\x44OUBLE\x10\x03\x12\n\n\x06STRING\x10\x04\x12\x0c\n\x08PROTOBUF\x10\x05'
)

_PARAMTYPE = _descriptor.EnumDescriptor(
  name='ParamType',
  full_name='apollo.cyber.proto.ParamType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NOT_SET', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BOOL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DOUBLE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STRING', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROTOBUF', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=401,
  serialized_end=482,
)
_sym_db.RegisterEnumDescriptor(_PARAMTYPE)

ParamType = enum_type_wrapper.EnumTypeWrapper(_PARAMTYPE)
NOT_SET = 0
BOOL = 1
INT = 2
DOUBLE = 3
STRING = 4
PROTOBUF = 5



_PARAM = _descriptor.Descriptor(
  name='Param',
  full_name='apollo.cyber.proto.Param',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='apollo.cyber.proto.Param.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='apollo.cyber.proto.Param.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type_name', full_name='apollo.cyber.proto.Param.type_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bool_value', full_name='apollo.cyber.proto.Param.bool_value', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='int_value', full_name='apollo.cyber.proto.Param.int_value', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='double_value', full_name='apollo.cyber.proto.Param.double_value', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='string_value', full_name='apollo.cyber.proto.Param.string_value', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proto_desc', full_name='apollo.cyber.proto.Param.proto_desc', index=7,
      number=8, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='oneof_value', full_name='apollo.cyber.proto.Param.oneof_value',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=52,
  serialized_end=263,
)


_NODENAME = _descriptor.Descriptor(
  name='NodeName',
  full_name='apollo.cyber.proto.NodeName',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='apollo.cyber.proto.NodeName.value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=265,
  serialized_end=290,
)


_PARAMNAME = _descriptor.Descriptor(
  name='ParamName',
  full_name='apollo.cyber.proto.ParamName',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='apollo.cyber.proto.ParamName.value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=292,
  serialized_end=318,
)


_BOOLRESULT = _descriptor.Descriptor(
  name='BoolResult',
  full_name='apollo.cyber.proto.BoolResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='apollo.cyber.proto.BoolResult.value', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=320,
  serialized_end=347,
)


_PARAMS = _descriptor.Descriptor(
  name='Params',
  full_name='apollo.cyber.proto.Params',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='param', full_name='apollo.cyber.proto.Params.param', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=349,
  serialized_end=399,
)

_PARAM.fields_by_name['type'].enum_type = _PARAMTYPE
_PARAM.oneofs_by_name['oneof_value'].fields.append(
  _PARAM.fields_by_name['bool_value'])
_PARAM.fields_by_name['bool_value'].containing_oneof = _PARAM.oneofs_by_name['oneof_value']
_PARAM.oneofs_by_name['oneof_value'].fields.append(
  _PARAM.fields_by_name['int_value'])
_PARAM.fields_by_name['int_value'].containing_oneof = _PARAM.oneofs_by_name['oneof_value']
_PARAM.oneofs_by_name['oneof_value'].fields.append(
  _PARAM.fields_by_name['double_value'])
_PARAM.fields_by_name['double_value'].containing_oneof = _PARAM.oneofs_by_name['oneof_value']
_PARAM.oneofs_by_name['oneof_value'].fields.append(
  _PARAM.fields_by_name['string_value'])
_PARAM.fields_by_name['string_value'].containing_oneof = _PARAM.oneofs_by_name['oneof_value']
_PARAMS.fields_by_name['param'].message_type = _PARAM
DESCRIPTOR.message_types_by_name['Param'] = _PARAM
DESCRIPTOR.message_types_by_name['NodeName'] = _NODENAME
DESCRIPTOR.message_types_by_name['ParamName'] = _PARAMNAME
DESCRIPTOR.message_types_by_name['BoolResult'] = _BOOLRESULT
DESCRIPTOR.message_types_by_name['Params'] = _PARAMS
DESCRIPTOR.enum_types_by_name['ParamType'] = _PARAMTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Param = _reflection.GeneratedProtocolMessageType('Param', (_message.Message,), {
  'DESCRIPTOR' : _PARAM,
  '__module__' : 'cyber.proto.parameter_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.proto.Param)
  })
_sym_db.RegisterMessage(Param)

NodeName = _reflection.GeneratedProtocolMessageType('NodeName', (_message.Message,), {
  'DESCRIPTOR' : _NODENAME,
  '__module__' : 'cyber.proto.parameter_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.proto.NodeName)
  })
_sym_db.RegisterMessage(NodeName)

ParamName = _reflection.GeneratedProtocolMessageType('ParamName', (_message.Message,), {
  'DESCRIPTOR' : _PARAMNAME,
  '__module__' : 'cyber.proto.parameter_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.proto.ParamName)
  })
_sym_db.RegisterMessage(ParamName)

BoolResult = _reflection.GeneratedProtocolMessageType('BoolResult', (_message.Message,), {
  'DESCRIPTOR' : _BOOLRESULT,
  '__module__' : 'cyber.proto.parameter_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.proto.BoolResult)
  })
_sym_db.RegisterMessage(BoolResult)

Params = _reflection.GeneratedProtocolMessageType('Params', (_message.Message,), {
  'DESCRIPTOR' : _PARAMS,
  '__module__' : 'cyber.proto.parameter_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.proto.Params)
  })
_sym_db.RegisterMessage(Params)


# @@protoc_insertion_point(module_scope)
